@@ -114,9 +114,10 @@ Rx[:mx_fa_clean]=     /#{Mx[:fa_o]}.+?#{Mx[:fa_c]}|#{Mx[:pa_o]}.+?#{Mx[:pa_c]}|#
 Rx[:lv],Rx[:lv_1],Rx[:lv_2],Rx[:lv_3],Rx[:lv_4],Rx[:lv_5],Rx[:lv_6],Rx[:lv_7],Rx[:lv_8],Rx[:lv_9]=
   /〔([1-9]):(\S*?)〕/,/#{Mx[:lv_o_1]}(\S*?)#{Mx[:lv_c]}/,/#{Mx[:lv_o_2]}(\S*?)#{Mx[:lv_c]}/,/#{Mx[:lv_o_3]}(\S*?)#{Mx[:lv_c]}/,/#{Mx[:lv_o_4]}(\S*?)#{Mx[:lv_c]}/,/#{Mx[:lv_o_5]}(\S*?)#{Mx[:lv_c]}/,/#{Mx[:lv_o_6]}(\S*?)#{Mx[:lv_c]}/,/#{Mx[:lv_o_7]}(\S*?)#{Mx[:lv_c]}/,/#{Mx[:lv_o_8]}(\S*?)#{Mx[:lv_c]}/,/#{Mx[:lv_o_9]}(\S*?)#{Mx[:lv_c]}/
 Rx[:meta]=/#{Mx[:meta_o]}(\S+?)#{Mx[:meta_c]}/
-Dx[:url_o]='‹';   Dx[:url_c]='›'
+Dx[:url_o]='‹';          Dx[:url_c]='›'
 Dx[:url_o_xml]='&lt;';   Dx[:url_c_xml]='&gt;'
-Dx[:rel_o]='‹';   Dx[:rel_c]='›' # Dx[:rel_o]='「';   Dx[:rel_c]='」'
+Dx[:rel_o]='‹';          Dx[:rel_c]='›' # Dx[:rel_o]='「';   Dx[:rel_c]='」'
+Dx[:lt_xml]='&lt;';      Dx[:gt_xml]='&gt;'
 Tex[:backslash]="\\\\"
 Tex[:backslash]="\\\\"
 Tex[:tilde]='\\\\\\~'
@@ -172,6 +173,7 @@ Db[:col_filesize]=10
 Db[:col_info_note]=2500
 Gt[:grotto]='sisu:'
 Gt[:src]='src'
+Gt[:pod]='pod'
 Gt[:po]='po4a/po'
 Gt[:pot]='po4a/pot'
 Gt[:image]='mm/image'
