@@ -482,8 +482,8 @@ module SiSU_document_structure_extract
       meta=[]
       dir=SiSU_Env::Info_env.new(@md.fns)
       base_html="#{dir.url.root}/#{@md.fnb}"
-      l=SiSU_Env::Standardise_language.new.file_to_language(@md.fns)
-      language=l[:l]
+      l=SiSU_Env::Standardise_language.new(@md.opt.lng).language
+      language=l[:n]
       tr=SiSU_Translate::Source.new(@md,language)
       meta << @pb
       h={ ln: 2, obj: 'Metadata', ocn_: false }
