@@ -85,7 +85,7 @@ module SiSU_Plaintext
           path=env.path.output_tell
           tool=(@opt.cmd =~/[MVv]/) \
           ? "#{env.program.text_editor} #{md.file.output_path.txt.dir}/#{md.file.base_filename.txt}" \
-          : @opt.fns
+          : "[#{@opt.f_pth[:lng_is]}] #{@opt.fns}"
           @opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,'Plaintext',tool).green_hi_blue \
           : SiSU_Screen::Ansi.new(@opt.cmd,'Plaintext',tool).green_title_hi
@@ -316,6 +316,7 @@ WOK
             dob.obj.gsub!(/#{Mx[:gl_o]}#125#{Mx[:gl_c]}/,'}')
             dob.obj.gsub!(/#{Mx[:gl_o]}#126#{Mx[:gl_c]}/,'~')
             dob.obj.gsub!(/#{Mx[:gl_o]}#169#{Mx[:gl_c]}/,'©')
+            dob.obj.gsub!(/#{Mx[:gl_o]}#092#{Mx[:gl_c]}/,'\\')
           end
           if dob.of=='block'                                   # watch
             dob.obj.gsub!(/#{Mx[:gl_o]}●#{Mx[:gl_c]}/,"* ")
