@@ -69,7 +69,6 @@ module SiSU_po4a
   class Source
     @@opt_src,@@opt_trn,@@opt_src_,@@opt_trn_,@@md_src,@@md_trn=nil,nil,nil,nil,nil,nil
     def initialize(opt,fn=nil)
-      @opt=opt
       @opt,@fn=opt,fn
       #unless @opt.fns =~/(.+?\.(?:-|ssm\.)?sst)$/
       #  puts "#{@opt.fns} not a processed file type"
@@ -77,7 +76,6 @@ module SiSU_po4a
       r=Px[:lng_lst].join('|')
       r.gsub!(/\|en\|/,'|')
       @lang_regx=%r{(?:#{r})}
-#     @lang_regx=%r{(?:es|fr)}
       if opt.fns =~/\S+?~#{@lang_regx}\.ss[mti]/ \
       and opt.f_pth[:lng]!='en'
         @@opt_src_=false
@@ -178,13 +176,8 @@ module SiSU_po4a
       end
       def songsheet
 ############## BUG @fn changes value
-#p __LINE__
-#p @fn
         fn=@fn
         pot=pot_markup(@data_src,@data_trn)
-#p __LINE__
-#p @fn
-#p fn
         publish(fn,pot)
       end
       def extract_endnotes(dob='')                                   #% Used for extraction of endnotes from paragraphs
@@ -946,11 +939,11 @@ GSUB
         unless @md.opt.cmd =~/M/
           require_relative 'git'                           # git.rb
           git=SiSU_Git::Source.new(@md.opt)
-          git.create_file_structure_git unless FileTest.directory?(@file.output_path.pot_git)
+          git.create_file_structure_git unless FileTest.directory?(@file.output_path.pot_git.dir)
           if @md.opt.f_pth[:lng] =='en'
-            cp(@file.place_file.pot, @file.output_path.pot_git)
+            cp(@file.place_file.pot.dir, @file.output_path.pot_git.dir)
           else # naive, work on -->
-            cp(@file.place_file.po, @file.output_path.po_git) #unless FileTest.file?(@file.place_file.po_git)
+            cp(@file.place_file.po.dir, @file.output_path.po_git.dir) #unless FileTest.file?(@file.place_file.po_git.dir)
           end
           git.read
         end
