@@ -103,11 +103,11 @@ module SiSU_TeX
     def song
       begin
         @md=@particulars.md
-        SiSU_Screen::Ansi.new(@opt.cmd,'LaTeX/PDF',@md.fns).green_title_hi unless @opt.cmd =~/q/
+        SiSU_Screen::Ansi.new(@opt.cmd,'LaTeX/PDF',"[#{@opt.f_pth[:lng_is]}] #{@opt.fns}").green_title_hi unless @opt.cmd =~/q/
         if @opt.cmd =~/[MVv]/
           path=@env.url.output_tell
           SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.program.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_l}pdf").flow
-          SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.program.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_p}pdf").flow
+          SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@opt.fns} #{@env.program.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_p}pdf").flow
         end
         @md=@particulars.md
         $flag=@md.opt.cmd                                                          #introduced to pass 0 for no object citation numbers... to texpdf_format
@@ -349,6 +349,8 @@ module SiSU_TeX
             if dob.tmp =~/#{Mx[:lnk_o]}.+?#{Mx[:lnk_c]}#{Mx[:rel_o]}\S+?#{Mx[:rel_c]}/
               dob.tmp=SiSU_TeX_Pdf::Format_text_object.new(@md,dob.tmp).url_str_internal(dob.tmp)
             end
+          elsif dob.is =='code'
+            dob.tmp=SiSU_TeX_Pdf::Special_characters.new(@md,dob.tmp).special_characters_code
           elsif dob.is =='break'
             if dob.obj==Mx[:br_page]; dob.tmp='\newpage'
             elsif dob.obj==Mx[:br_page_new]; dob.tmp='\clearpage'
@@ -460,10 +462,6 @@ module SiSU_TeX
             dob
           else 'error' #should never occur
           end
-          if dob.tmp =~/<=curly/ #takes care of escaped curly braces, expand
-            sp_char=SiSU_TeX_Pdf::Special_characters.new(@md,dob)
-            dob.tmp=sp_char.special_characters_curly(dob.tmp)
-          end
           dob=enclose(dob) unless dob.tmp =~/^$/
           dob
         else
@@ -531,10 +529,6 @@ module SiSU_TeX
             dob.tmp.gsub!(/\s*(?:#{Mx[:br_line]}|#{Mx[:br_nl]})\s*/,' \newline ')   #% tread with care
             dob.tmp.gsub!(/(\.#{Tex[:tilde]}\S*\s*|<:\S+>|#{Mx[:fa_o]}.*?#{Mx[:fa_c]}|#{Mx[:gr_o]}.*?#{Mx[:gr_c]}|<!.*?!>|<!>)/,' ')   #% tread with care
           end
-          if dob.tmp =~/<=curly/ #takes care of escaped curly braces, expand
-            sp_char=SiSU_TeX_Pdf::Special_characters.new(@md,dob)
-            dob.tmp=sp_char.special_characters_curly(dob.tmp)
-          end
           dob
         end
         if dob.tmp =~/(?:#{Mx[:url_o]}\S+?#{Mx[:url_c]}|image\b)/m \
@@ -582,6 +576,18 @@ module SiSU_TeX
 \\newcommand{\\Codeblock}[1]{\\normaltext\\raggedright\\small\\ttfamily\\texbackslash#1}
 \\newcommand{\\monosp}[1]{\\normaltext\\ttfamily\\texbackslash#1}
 \\newcommand{\\parasep}{\\\\ \\begin{center}*\\hspace{2em}*\\hspace{2em}*\\end{center} \\\\}
+\\newcommand{\\hardspace}{{~}}
+%\\newcommand{\\hardspace}{\\hspace{.5em}}
+\\newcommand{\\caret}{{\\^{~}}}
+\\newcommand{\\pipe}{{\\textbar}}
+\\newcommand{\\curlyopen}{\{}
+\\newcommand{\\curlyclose}{\}}
+\\newcommand{\\lt}{{\UseTextSymbol{OML}{<}}}
+\\newcommand{\\gt}{{\UseTextSymbol{OML}{>}}}
+\\newcommand{\\slash}{{/}}
+\\newcommand{\\underscore}{\\_}
+\\newcommand{\\exclaim}{\\Verbatim{!}}
+% (tilde hash amp affected by http)
 % \\sloppy
 \\begin{document}
 WOK
