@@ -86,7 +86,7 @@ module SiSU_XHTML
 
           tool=if @opt.cmd =~/[MV]/; "#{@env.program.web_browser} file://#{@md.file.output_path.xhtml.dir}/#{@md.file.base_filename.xhtml}#{path}/#{@md.fnb}/#{@md.fn[:xhtml]}\n\t#{@env.program.xml_viewer} file://#{@md.file.output_path.xhtml.dir}/#{@md.file.base_filename.xhtml}#{path}/#{@md.fnb}/#{@md.fn[:xhtml]}"
           elsif @opt.cmd =~/v/; "#{@env.program.web_browser} file://#{@md.file.output_path.xhtml.dir}/#{@md.file.base_filename.xhtml}"
-          else @opt.fns
+          else "[#{@opt.f_pth[:lng_is]}] #{@opt.fns}"
           end
           @opt.cmd=~/[MVvz]/ \
           ? SiSU_Screen::Ansi.new(@opt.cmd,'invert','XHTML',tool).colorize \
